@@ -1,12 +1,7 @@
 #!/bin/sh
 
 # defaults
-if [ "$1" == '-v2' ]; then
-   DRIVERPATH="/opt/cleven/compat-wireless-v2" 
-else
-   DRIVERPATH="/opt/cleven/compat-wireless-v1" 
-fi
-
+DRIVERPATH="/opt/lib/modules/$1/" 
 FILEPATH="/home/user/.cleven"
 
 # Save mac address
@@ -26,13 +21,15 @@ rmmod rfkill_backport 2>/dev/null
 rmmod compat_firmware_class 2>/dev/null
 rmmod compat 2>/dev/null
 # Load bleeding-edge wl1251
-insmod $DRIVERPATH/compat.ko
-insmod $DRIVERPATH/rfkill_backport.ko
-insmod $DRIVERPATH/cfg80211.ko
-insmod $DRIVERPATH/mac80211.ko
-insmod $DRIVERPATH/wl1251.ko
-insmod $DRIVERPATH/wl1251_spi.ko
+
+insmod $DRIVERPATH/updates/compat/compat.ko
+insmod $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko
+insmod $DRIVERPATH/updates/net/wireless/cfg80211.ko
+insmod $DRIVERPATH/updates/net/mac80211/mac80211.ko
+insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251.ko
+insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko
+   
 # Restore mac address
 ifconfig wlan0 down hw ether "$MACADDR"
 
-echo "Custom wl1251 $1 module loaded (with injection) :)"
\ No newline at end of file
+echo "Custom wl1251 module loaded (with injection) :)"
\ No newline at end of file
